@@ -1,19 +1,44 @@
-#' Calculate the categories based on the cutoff
+#' Generic for Statistical Approach
 #'
-#' @param data A preprocessed wide dataframe with at least column `id`, `pre`
-#'   and `post`
-#' @param m_functional Mean of functional population
-#' @param sd_functional SD of functional population
-#' @param type Cutoff type, available are `"a"`, `"b"`, and `"c"`
-#' @param direction Which direction is better? 1 = higher, -1 = lower
+#' This is an internal generic and should not be called directly. Depending on
+#' the different cutoff method requested by the user, the appropriate method is
+#' called. It calculates the cutoff and according clinical significance category
+#' for each participant.
 #'
-#' @importFrom stats sd relevel
+#' @param data A pre-processed wide data frame with at least column `id`, `pre`
+#'   and `post` and class `cs_*`
+#' @param ... Additional arguments for the respective cutoff method
 #'
 #' @return A list with cutoff info and participant wise info on cutoff
 #'   categorization
 #'
-#' @noRd
-.calc_cutoff_jt_data <- function(data, m_clinical, sd_clinical, m_functional, sd_functional, type = "a", direction = 1) {
+#' @keywords internal
+#' @export
+calc_cutoff_from_data <- function(data,
+                                  ...) {
+  UseMethod("calc_cutoff_from_data")
+}
+
+
+#' Calculate the categories based on the cutoff
+#'
+#' @inheritParams calc_rci
+#' @param m_functional Mean of functional population
+#' @param sd_functional SD of functional population
+#' @param type Cutoff type, available are `"a"`, `"b"`, and `"c"`
+#'
+#' @keywords internal
+#' @export
+calc_cutoff_from_data.default <- function(data,
+                                          m_clinical,
+                                          sd_clinical,
+                                          m_functional,
+                                          sd_functional,
+                                          type = "a",
+                                          direction = 1,
+                                          ...) {
+  data <- data[["data"]]
+
   # Calculate cutoff
   cutoff_info <- .calc_cutoff_jt(
     m_clinical = m_clinical,
@@ -26,43 +51,52 @@
 
   cutoff <- cutoff_info[["value"]]
 
-  data_cutoff_criteria <- data %>%
-    mutate(
+  data_cutoff_criteria <- data |>
+    dplyr::mutate(
       clinical_pre    = ifelse(direction * pre < direction * cutoff, TRUE, FALSE),
       functional_post = ifelse(direction * post > direction * cutoff, TRUE, FALSE),
-    ) %>%
-    select(id, clinical_pre, functional_post)
+    ) |>
+    dplyr::select(id, clinical_pre, functional_post)
 
   # Bind cutoff info and data with cutoff criteria together for further
   # calculations
-  list(
+  out <- list(
     info = cutoff_info,
     direction = direction,
     data = data_cutoff_criteria
   )
+
+  class(out) <- c("cs_statistical", class(out))
+  out
 }
 
 
 #' Calculate cs_indiv
 #'
-#' @param data A preprocessed data frame with at least column `post`
 #' @param m_clinical Mean of clinical population
 #' @param sd_clinical SD of clinical population
-#' @param m_functional Mean of functional population
-#' @param sd_functional SD of functional population
 #' @param m_post Mean of post measurement
 #' @param sd_post SD of post measurement
 #' @param reliability Instrument's reliability
-#' @param type Cutoff type, available are `"a"`, `"b"`, and `"c"`
-#' @param direction Which direction is better? 1 = higher, -1 = lower
+#' @param critical_value The critical value for the RCI decision, should be
+#'    1.65 if significance_level = 0.05
 #'
-#' @importFrom rlang .data
-#'
-#' @return A list with cutoff info and participant wise info on cutoff
-#'   categorization
-#'
-#' @noRd
-.calc_cutoff_ha_data <- function(data, m_clinical, sd_clinical, m_functional, sd_functional, m_post, sd_post, reliability, type = "a", direction = 1) {
+#' @keywords internal
+#' @export
+calc_cutoff_from_data.cs_ha <- function(data,
+                                        m_clinical,
+                                        sd_clinical,
+                                        m_functional,
+                                        sd_functional,
+                                        m_post,
+                                        sd_post,
+                                        reliability,
+                                        type = "a",
+                                        direction = 1,
+                                        critical_value = 1.65,
+                                        ...) {
+  data <- data[["data"]]
+
   se_measurement <- .calc_se_measurement(sd_pre = sd_clinical, reliability = reliability)
   reliability_clinical <- .calc_reliability_ha(sd = sd_clinical, se_measurment = se_measurement)
   reliability_post <- .calc_reliability_ha(sd = sd_post, se_measurment = se_measurement)
@@ -81,14 +115,16 @@
 
   cutoff <- cutoff_info[["value"]]
 
-  data_cutoff_criteria <- data %>%
-    mutate(
+  data_cutoff_criteria <- data |>
+    dplyr::mutate(
       cs_indiv = (m_post + (post - m_post) * reliability_post - cutoff) / (sqrt(reliability_post) * se_measurement),
-      functional_post = ifelse(direction * cs_indiv > 1.65, TRUE, FALSE)
-    ) %>%
-    select(id, cs_indiv, functional_post)
+      clinical_pre = direction * pre < direction * cutoff,
+      functional_post = clinical_pre & direction * cs_indiv > critical_value,
+      clinical_post = !clinical_pre & direction * cs_indiv < -critical_value
+    ) |>
+    dplyr::select(id, cs_indiv, clinical_pre, functional_post, clinical_post)
 
-  list(
+  out <- list(
     info = cutoff_info,
     reliability_post = reliability_post,
     m_post = m_post,
@@ -96,6 +132,9 @@
     direction = direction,
     data = data_cutoff_criteria
   )
+
+  class(out) <- c("cs_statistical", class(out))
+  out
 }
 
 
